@@ -17,6 +17,7 @@ ALTIDX = vcf_util.VCF_COL.index('ALT')
 INFOIDX = vcf_util.VCF_COL.index('INFO')
 FORMATIDX = vcf_util.VCF_COL.index('FORMAT')
 SAMPLESTARTIDX = vcf_util.VCF_COL.index('SAMPLESTART')
+DATAHEADER = {}
 
 class VCFAnnotator():
     vcfheader = None
@@ -30,11 +31,11 @@ class VCFAnnotator():
         self.out = self.opt.out
         self.dslist = DataSourceList(self.opt.ds)
         self.dslist.tmp_clinvar_idmap = file_util.tmp_load_clinvar_idmap()
-        if self.opt.sourcefile != "":
+        if len(self.opt.sourcefile) > 0:
             self.dslist.sourcefile = self.opt.sourcefile
             self.dslist.sourcefile2 = self.opt.sourcefile
-        if self.opt.single_source_mode:
-            self.dslist.single_source_mode = self.opt.single_source_mode
+        if self.opt.use_raw_source:
+            self.dslist.use_raw_source = self.opt.use_raw_source
 
         self.vcfreader = VCFReader(self.opt)
         if 'vcf' in self.opt.outtype:
@@ -425,30 +426,29 @@ class VCFVariant:
             self.record[INFOIDX] = vcf_util.add_info(self.record[INFOIDX], "MUTANNO=" + '|'.join(values))
 
     def fix_multiallele_pl(self):
-        if "MULTIALLELE=" in self.record[INFOIDX]:
-            rst = vcf_util.pars_info_field(self.record[INFOIDX])
-            this_geno = self.ref + '/' + self.alt
-            
-            multiallele_key = vcf_util.decode_value(rst['MULTIALLELE'][0][0])
-            this_numgeno = vcf_util.get_numgt_from_multiallele(this_geno, multiallele_key.strip().split(' ')[-1])
-            # print('>this_geno:', this_geno, this_numgeno,  multiallele_key.strip().split(' ')[-1])
-
-            for samplegeno in rst['SAMPLEGENO']:
-                sgeno = struct_util.mkdict(self.infoheader['SAMPLEGENO']['Format'], samplegeno)
-                samplecolidx = self.colnames.index(sgeno['SAMPLEID'])
-                format_list = self.record[FORMATIDX].split(':')
-                sample_genotype = self.record[samplecolidx].split(':')
-
-                pl = sample_genotype[format_list.index('PL')].split(',')
-                new_pl = vcf_util.get_biallelepl_multiallelepl(this_numgeno, pl)
-                sample_genotype[format_list.index('PL')] = ','.join(new_pl)
-
-                # fix num_genotype (for temporary usage) #########################################################################
-                new_gt = vcf_util.get_numgt(sgeno['GT'], self.ref, self.alt, delimiter=sample_genotype[format_list.index('GT')][1])
-                sample_genotype[format_list.index('GT')] = new_gt
-                # fix num_genotype (for temporary usage) #########################################################################
-
-                self.record[samplecolidx] = ':'.join(sample_genotype)
+        pass
+        # if "MULTIALLELE=" in self.record[INFOIDX]:
+        #     rst = vcf_util.pars_info_field(self.record[INFOIDX])
+        #     this_geno = self.ref + '/' + self.alt  
+        #     multiallele_key = vcf_util.decode_value(rst['MULTIALLELE'][0][0])
+        #     this_numgeno = vcf_util.get_numgt_from_multiallele(this_geno, multiallele_key.strip().split(' ')[-1])
+        #     # print('>this_geno:', this_geno, this_numgeno,  multiallele_key.strip().split(' ')[-1])
+        #     for samplegeno in rst['SAMPLEGENO']:
+        #         # print(samplegeno)
+        #         sgeno = struct_util.mkdict(self.infoheader['SAMPLEGENO']['Format'], samplegeno)
+        #         samplecolidx = self.colnames.index(sgeno['SAMPLEID'])
+        #         format_list = self.record[FORMATIDX].split(':')
+        #         sample_genotype = self.record[samplecolidx].split(':')
+        #         if len(sample_genotype) > format_list.index('PL'):
+        #             pl = sample_genotype[format_list.index('PL')].split(',')
+        #             if len(pl) >= 6:
+        #                 new_pl = vcf_util.get_biallelepl_multiallelepl(this_numgeno, pl)
+        #                 sample_genotype[format_list.index('PL')] = ','.join(new_pl)
+        #                 # fix num_genotype (for temporary usage) #########################################################################
+        #                 new_gt = vcf_util.get_numgt(sgeno['GT'], self.ref, self.alt, delimiter=sample_genotype[format_list.index('GT')][1])
+        #                 sample_genotype[format_list.index('GT')] = new_gt
+        #                 # fix num_genotype (for temporary usage) #########################################################################
+        #                 self.record[samplecolidx] = ':'.join(sample_genotype)
 
     def add_hg19_in_infofield(self, liftover_hg38_hg19, add_hgvs=False):
         hg19 = ""
